@@ -1,24 +1,27 @@
-from pathlib import Path
-from pkg_resources import resource_filename  # type: ignore
-from tree_sitter_type_provider import *
-
-import sys
-import tree_sitter
-import typing
 import os
+import pathlib
+import platform
+import sys
+import typing
+
+import pkg_resources  # type: ignore
+import tree_sitter
+import tree_sitter_type_provider
 
 
-class TreeSitterTalon(TreeSitterTypeProvider):
-    def resource_path(self, resource_name: str) -> Path:
+class TreeSitterTalon(tree_sitter_type_provider.TreeSitterTypeProvider):
+    def resource_path(self, resource_name: str) -> pathlib.Path:
         dirname = os.path.dirname(__file__)
         try:
-            filename = Path(resource_filename("tree_sitter_talon", resource_name))
+            filename = pathlib.Path(
+                pkg_resources.resource_filename("tree_sitter_talon", resource_name)
+            )
             if filename.exists() and filename.match(f"dirname/**"):
                 return filename
         except (KeyError, ModuleNotFoundError):
             pass
 
-        filename = Path(dirname) / resource_name
+        filename = pathlib.Path(dirname) / resource_name
         if filename.exists():
             return filename
 
@@ -29,25 +32,33 @@ class TreeSitterTalon(TreeSitterTypeProvider):
         return str(self.resource_path("data/tree-sitter-talon"))
 
     @property
-    def data_path(self) -> Path:
+    def data_path(self) -> pathlib.Path:
         return self.resource_path("data")
 
     @property
-    def library_path(self) -> str:
-        library_name = {
-            "linux": "talon.so",
-            "darwin": "talon.dylib",
-            "win32": "talon.dll",
-        }[sys.platform]
-        return str(self.data_path / library_name)
+    def library_name(self) -> str:
+        machine = platform.machine()
+        supported_systems: dict[str, str] = {
+            "Linux": "so",
+            "Darwin": "dylib",
+            "Windows": "dll",
+        }
+        ext = supported_systems.get(platform.system(), None)
+        if ext is None:
+            raise RuntimeError(f"Unsupported platform '{platform.system()}'")
+        return f"talon-{machine}.{ext}"
 
     @property
-    def node_types_path(self) -> Path:
+    def library_path(self) -> pathlib.Path:
+        return self.data_path / self.library_name
+
+    @property
+    def node_types_path(self) -> pathlib.Path:
         return self.resource_path("data/tree-sitter-talon/src/node-types.json")
 
     def __init__(self, *, encoding: str = "utf-8"):
         # Read node-types.json
-        node_types = NodeType.schema().loads( # type: ignore
+        node_types = tree_sitter_type_provider.NodeType.schema().loads(  # type: ignore
             self.node_types_path.read_text(encoding=encoding), many=True
         )
 
@@ -68,18 +79,22 @@ class TreeSitterTalon(TreeSitterTypeProvider):
         )
 
         # Build tree-sitter-talon
-        tree_sitter.Language.build_library(self.library_path, [self.repository_path])
-        self.language = tree_sitter.Language(self.library_path, "talon")
+        if os.getenv("CI") and self.library_path.exists():
+            pass
+        else:
+            tree_sitter.Language.build_library(
+                str(self.library_path), [self.repository_path]
+            )
+        self.language = tree_sitter.Language(str(self.library_path), "talon")
         self.parser = tree_sitter.Parser()
         self.parser.set_language(self.language)
 
-        self.NodeTypeName = NodeTypeName
-        self.NodeFieldName = NodeFieldName
-        self.NodeTypeError = NodeTypeError
-        self.Point = Point
-        self.Node = Node
-        self.Leaf = Leaf
-        self.Branch = Branch
+        self.NodeTypeError = tree_sitter_type_provider.NodeTypeError
+        self.NodeTypeName = tree_sitter_type_provider.NodeTypeName
+        self.Node = tree_sitter_type_provider.Node
+        self.Leaf = tree_sitter_type_provider.Leaf
+        self.Branch = tree_sitter_type_provider.Branch
+        self.Point = tree_sitter_type_provider.Point
 
     def parse(
         self,
@@ -87,7 +102,11 @@ class TreeSitterTalon(TreeSitterTypeProvider):
         *,
         has_header: typing.Optional[bool] = None,
         encoding: str = "utf-8",
-    ) -> typing.Union[typing.Sequence[Node], Node, None]:
+    ) -> typing.Union[
+        typing.Sequence[tree_sitter_type_provider.Node],
+        tree_sitter_type_provider.Node,
+        None,
+    ]:
         tree = self.parse_as_tree_sitter(
             contents, has_header=has_header, encoding=encoding
         )
@@ -95,11 +114,15 @@ class TreeSitterTalon(TreeSitterTypeProvider):
 
     def parse_file(
         self,
-        path: typing.Union[str, Path],
+        path: typing.Union[str, pathlib.Path],
         *,
         has_header: typing.Optional[bool] = None,
         encoding: str = "utf-8",
-    ) -> typing.Union[typing.Sequence[Node], Node, None]:
+    ) -> typing.Union[
+        typing.Sequence[tree_sitter_type_provider.Node],
+        tree_sitter_type_provider.Node,
+        None,
+    ]:
         tree = self.parse_file_as_tree_sitter(
             path, has_header=has_header, encoding=encoding
         )
@@ -122,13 +145,13 @@ class TreeSitterTalon(TreeSitterTypeProvider):
 
     def parse_file_as_tree_sitter(
         self,
-        path: typing.Union[str, Path],
+        path: typing.Union[str, pathlib.Path],
         *,
         has_header: typing.Optional[bool] = None,
         encoding: str = "utf-8",
     ) -> tree_sitter.Tree:
-        if not isinstance(path, Path):
-            path = Path(path)
+        if not isinstance(path, pathlib.Path):
+            path = pathlib.Path(path)
         contents = path.read_bytes()
         return self.parse_as_tree_sitter(
             contents, has_header=has_header, encoding=encoding
